@@ -2,9 +2,8 @@ package Plack::Middleware::Security::Simple;
 
 # ABSTRACT: A simple security filter for Plack
 
-use v5.10.0;
+use v5.14;
 
-use strict;
 use warnings;
 
 use parent qw( Plack::Middleware );
@@ -18,7 +17,7 @@ use Plack::Util::Accessor qw( rules handler status );
 
 # RECOMMEND PREREQ: Ref::Util::XS
 
-our $VERSION = 'v0.8.3';
+our $VERSION = 'v0.9.1';
 
 
 sub prepare_app {
@@ -80,7 +79,7 @@ Plack::Middleware::Security::Simple - A simple security filter for Plack
 
 =head1 VERSION
 
-version v0.8.3
+version v0.9.1
 
 =head1 SYNOPSIS
 
@@ -144,6 +143,14 @@ This can be used if you are writing L<fail2ban> filters.
 This is the HTTP status code that the default L</handler> will return
 when a resource is blocked.  It defaults to 400 (Bad Request).
 
+=head1 SUPPORT FOR OLDER PERL VERSIONS
+
+Since v0.9.0, the this module requires Perl v5.14 or later.
+
+If you need this module on Perl v5.10, please use one of the v0.8.x
+versions of this module.  Significant bug or security fixes may be
+backported to those versions.
+
 =head1 SEE ALSO
 
 L<Hash::Match>
@@ -172,7 +179,7 @@ Robert Rothenberg <rrwo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014,2018-2022 by Robert Rothenberg.
+This software is Copyright (c) 2014,2018-2023 by Robert Rothenberg.
 
 This is free software, licensed under:
 
